@echo off
rem ###############################################################################
rem #
rem # Licensed Materials - Property of IBM
rem #
rem # (C) Copyright IBM Corp. 2023. All Rights Reserved.
rem #
rem # US Government Users Restricted Rights - Use, duplication or
rem # disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
rem #
rem ###############################################################################

echo.
SETLOCAL
rem This file is to be used with CP4BA 23.0.2 starter deployment to deploy the Content Platinum Demo artifacts (except Teamspace-related artifacts)

rem Set all variables according to your environment before executing this file

rem ----------------------------------------------------------------------------------------------------------
rem Specify below variables to launch the deployment automation with
rem ----------------------------------------------------------------------------------------------------------

rem 'ocLoginServer' and 'ocLoginToken' need to be specified

rem Value of the 'server' parameter as shown on the 'Copy login command' page in the OCP web console
SET ocLoginServer=REQUIRED
rem Value shown under 'Your API token is' or as 'token' parameter as shown on the 'Copy login command' page in the OCP web console
SET ocLoginToken=REQUIRED


rem Uncomment in case JVM throws an "Out Of Memory"-exception during the execution
rem SET jvmSettings=-Xms4096M

rem Uncomment in case GitHub is not accessible and all resources are already available locally
rem SET disableAccessToGitHub="-disableAccessToGitHub=true"

rem Proxy settings in case a proxy server needs to be used to access the GitHub resources
rem Uncomment at least the proxyScenario, proxyHost, and proxyPort lines and set values accordingly in case a proxy server needs to be used to access GitHub
rem Uncomment the lines proxyUser and proxyPwd too, in case the proxy server requires authentication
rem SET proxyScenario=GitHub
rem SET proxyHost=
rem SET proxyPort=
rem SET proxyUser=
rem SET proxyPwd=

rem Specific trace string for the boostrapping process (only uncomment if instructed to do so)
rem SET bootstrapDebugString="-bds=*=finest"

rem Specify a value if the log files should be written to a specific path, otherwise will be written to the location from which this file is executed
SET outputPath=

rem Change to true in case detailed output messages and/or trace messages should be printed to the console
SET printDetailedMessageToConsole=false
SET printTraceMessageToConsole=false

rem ----------------------------------------------------------------------------------------------------------
rem Construct the proxy settings for curl and deployment automation tool if proxy is configured
rem ----------------------------------------------------------------------------------------------------------

if defined proxyHost (
	if defined proxyUser (
		SET TOOLPROXYSETTINGS="-psc=%proxyScenario% -ph=%proxyHost% -pp=%proxyPort% -pu=%proxyUser% -ppwd=%proxyPwd%"
		
		if "%proxScenatio%"=="GitHub" (
			SET CURLPROXYSETTINGS="-x %proxyHost%:%proxyPort% -U %proxyUser%:%proxyPwd%"
		)
	) else (
		SET TOOLPROXYSETTINGS="-psc=%proxyScenario% -ph=%proxyHost% -pp=%proxyPort%"
		
		if "%proxScenatio%"=="GitHub" (
			SET CURLPROXYSETTINGS="-x %proxyHost%:%proxyPort%"
		)
	)
)

rem ----------------------------------------------------------------------------------------------------------
rem Global settings for the script (not to be modified by user)
rem ----------------------------------------------------------------------------------------------------------

rem CP4BA version
SET CP4BAVERSION=23.0.2
rem Deployment pattern of the CP4BA instance
SET DEPLOYMENTPATTERN=Starter
rem Name of the configuration file to use when running the deployment automation tool
SET CONFIGNAME=config-deploy-content
rem Automation script to use when running the deployment automation tool
SET AUTOMATIONSCRIPT=CreateContentPlatinumDemoArtifacts.json

rem Name of the source batch file passed to execution environment
SET SCRIPTNAME=configureContentPlatinumDemoStarter.bat
rem Name of the actual batch file passed to execution environment
SET FILENAME=%~nx0
rem Version of this script file passed to execution environment
SET SCRIPTVERSION=1.0.0

rem ----------------------------------------------------------------------------------------------------------
rem Validate that the deployment tool jar is available locally
rem ----------------------------------------------------------------------------------------------------------

rem Determine if the deployment automation tool is available and in case it is store it exact name to be used later to run it
for /f "tokens=*" %%i in ('dir /b * ^| findstr /l "DeploymentAutomation.jar"') do set TOOLFILENAME=%%i
	
rem In case not available/found print error and mark as validation failed
if not defined TOOLFILENAME (
	set toolValidationFailed=true
	echo   No version of the deployment automation jar could be found
) else (
	echo   Using local deployment automation jar file '%TOOLFILENAME%'
)
	
echo:

rem ----------------------------------------------------------------------------------------------------------
rem Validation that all required parameters are set
rem ----------------------------------------------------------------------------------------------------------

rem if 'ocLoginServer' variable is defined, ensure it is not at default value or empty, otherwise including not defined set marker that it is missing
if defined ocLoginServer (
	if "%ocLoginServer%"=="REQUIRED" (
		set ocLoginServerRequired=true
	) else (
		if "%ocLoginServer%"=="" (
			set ocLoginServerRequired=true
		) else (
			set INTERNALOCLOGINSERVER=-ocls=%ocLoginServer%
		)
	)
) else (
	set ocLoginServerRequired=true
)

rem if 'ocLoginToken' variable is defined, ensure it is not at default value or empty, otherwise including not defined set marker that it is missing
if defined ocLoginToken (
	if "%ocLoginToken%"=="REQUIRED" (
		set ocLoginTokenRequired=true
	) else (
		if "%ocLoginToken%"=="" (
			set ocLoginTokenRequired=true
		) else (
			set INTERNALOCLOGINTOKEN=-oclt=%ocLoginToken%
		)
	)
) else (
	set ocLoginTokenRequired=true
)

if defined ocLoginServerRequired ( 
	if not defined validationFailed (
		echo Validating configuration failed:
		set validationFailed=true
	)
	echo   Variable 'ocLoginServer' has not been defined/set
)

if defined ocLoginTokenRequired ( 
	if not defined validationFailed (
		echo Validating configuration failed:
		set validationFailed=true
	)
	echo   Variable 'ocLoginToken' has not been defined/set
)

if defined printDetailedMessageToConsole (
	if "%printDetailedMessageToConsole%"=="true" (
		set INTERNALPDMTOC=-pdmtc
	)
)
if defined printTraceMessageToConsole  (
	if "%printTraceMessageToConsole%"=="true" (
		set INTERALPTCTOC=-ptmtc
	)
)
if defined outputPath set INTERNALOUTPUTPATH="-op=%outputPath%"

if defined toolValidationFailed set overallValidationFailed=true
if defined validationFailed set overallValidationFailed=true

if defined overallValidationFailed (
	echo:
	echo Existing...
	exit /b 1;
)

echo Starting deployment automation tool...
echo:

java %jvmSettings% -jar %TOOLFILENAME% %bootstrapDebugString% "-sn=%FILENAME%" "-ss=%SCRIPTNAME%" "-sv=%SCRIPTVERSION%" %INTERNALOCLOGINSERVER% %INTERNALOCLOGINTOKEN% %TOOLPROXYSETTINGS% "-ibp=/%DEPLOYMENTPATTERN%" -c=%CONFIGNAME% -as=%AUTOMATIONSCRIPT% %INTERNALOUTPUTPATH% %INTERNALPDMTOC% %INTERALPTCTOC% -isLocalMode

ENDLOCAL