# This file is to be used with CP4BA 23.0.2 Starter deployment to configure the Content Platinum Demo artifacts (except Teamspace-related artifacts)

# Set all variables according to your environment before executing this file

#----------------------------------------------------------------------------------------------------------
# Specify below variables to launch the deployment automation with
#----------------------------------------------------------------------------------------------------------

# 'ocLoginServer' and 'ocLoginToken' need to be specified

# Value of the 'server' parameter as shown on the 'Copy login command' page in the OCP web console
ocLoginServer=REQUIRED
# Value shown under 'Your API token is' or as 'token' parameter as shown on the 'Copy login command' page in the OCP web console
ocLoginToken=REQUIRED


# Uncomment in case JVM throws an "Out Of Memory"-exception during the execution
#jvmSettings="-Xms4096M"

# Uncomment in case GitHub is not accessible and all resources are already available locally
#disableAccessToGitHub="-disableAccessToGitHub=true"

# Proxy settings in case a proxy server needs to be used to access the GitHub resources
# Uncomment at least the proxyScenario, proxyHost, and proxyPort lines and set values accordingly in case a proxy server needs to be used to access GitHub
# Uncomment the lines proxyUser and proxyPwd too, in case the proxy server requires authentication
#proxyScenario=GitHub
#proxyHost=
#proxyPort=
#proxyUser=
#proxyPwd=

# Specific trace string for the boostrapping process (only uncomment if instructed to do so)
#bootstrapDebugString="\"-dbs=*=finest\""

# Specify a value if the log files should be written to a specific path, otherwise will be written to the location from which this file is executed
outputPath=

# Change to true in case detailed output messages and/or trace messages should be printed to the console
printDetailedMessageToConsole=false
printTraceMessageToConsole=false

# ----------------------------------------------------------------------------------------------------------
# Construct the proxy settings for curl and deployment automation tool if proxy is configured
# ----------------------------------------------------------------------------------------------------------

if [ ! -z "${proxyHost+x}" ]
then
  if [ ! -z "${proxyUser+x}" ]
  then
     TOOLPROXYSETTINGS="-psc=${proxyScenario} -ph=${proxyHost} -pp=${proxyPort} -pu=${proxyUser} -ppwd=${proxyPwd}"

     if [[ "${proxyScenario}" == "GitHub" ]] 
     then
       CURLPROXYSETTINGS="-x ${proxyHost}:${proxyPort} -U ${proxyUser}:${proxyPwd}"
     fi
  else
    TOOLPROXYSETTINGS="-psc=${proxyScenario} -ph=${proxyHost} -pp=${proxyPort}"
    if [[ "${proxyScenario}" == "GitHub" ]] 
    then
       CURLPROXYSETTINGS="-x ${proxyHost}:${proxyPort}"
    fi
  fi
fi

# ----------------------------------------------------------------------------------------------------------
# Global settings for the script (not to be modified by user)
# ----------------------------------------------------------------------------------------------------------

# Source URL where the deployment automation jar can be retrieved from
TOOLSOURCE="https://api.github.com/repos/IBM/cp4ba-client-onboarding-scenario/contents/Deployment_Automation"
# CP4BA version
CP4BAVERSION="23.0.2"
# Deployment pattern of the CP4BA instance
DEPLOYMENTPATTERN="Starter"
# Name of the configuration file to use when running the deployment automation tool
CONFIGNAME="config-deploy-content"
# Automation script to use when running the deployment automation tool
AUTOMATIONSCRIPT="CreateContentPlatinumDemoArtifacts.json"

# Name of the source sh file passed to execution environment
SCRIPTNAME=configureContentPlatinumDemoStarter.sh
# Name of the actual sh file passed to execution environment
FILENAME=$0
# Version of this script file passed to execution environment
SCRIPTVERSION=1.0.0

# ----------------------------------------------------------------------------------------------------------
# Validate that the deployment tool jar is available locally
# ----------------------------------------------------------------------------------------------------------

toolValidationSuccess=true

if ls *DeploymentAutomation.jar 1> /dev/null 2>&1; then
  # get the latest version of the file
  TOOLFILENAME=$(ls *DeploymentAutomation.jar | tail -n 1)
    
  echo "  Using local deployment automation jar file '${TOOLFILENAME}'"
# if no file with the name found 
else
  toolValidationSuccess=false
  echo "  No version of the deployment automation jar could be found"
fi

echo

# ----------------------------------------------------------------------------------------------------------
# Validation that all required parameters are set
# ----------------------------------------------------------------------------------------------------------

validationSuccess=true

# Check that 'ocLoginServer' and 'ocLoginToken' are properly defined
if [ -z "${ocLoginServer+x}" ] || [[ "${ocLoginServer}" == "REQUIRED" ]] || [[ "${ocLoginServer}" == "" ]]
then
	if $validationSuccess
	then
		echo "Validating configuration failed:"
		validationSuccess=false
	fi
	echo "  Variable 'ocLoginServer' has not been defined/set"
else
	INTERNALOCLOGINSERVER=-ocls=${ocLoginServer}
fi

if [ -z "${ocLoginToken+x}" ] || [[ "${ocLoginToken}" == "REQUIRED" ]] || [[ "${ocLoginToken}" == "" ]]
then
	if $validationSuccess
	then
		echo "Validating configuration failed:"
		validationSuccess=false
	fi
	echo "  Variable 'ocLoginToken' has not been defined/set"
else
	INTERNALOCLOGINTOKEN=-oclt=${ocLoginToken}
fi

if [[ ! -z "${printDetailedMessageToConsole+x}" ]]
then
  if [[ "${printDetailedMessageToConsole}" == "true" ]]
  then
    INTERNALPDMTOC=-pdmtc
  fi
fi

if [[ ! -z "${printTraceMessageToConsole+x}" ]]
then
  if [[ "${printTraceMessageToConsole}" == "true" ]]
  then
    INTERALPTCTOC=-ptmtc
  fi
fi

if [[ ! -z "${outputPath+x}" ]]
then
	INTERNALOUTPUTPATH=\"-op=${outputPath}\"
fi

if ! $validationSuccess
then
  echo
fi

if ! $validationSuccess || ! $toolValidationSuccess
then
  echo "Exiting..."
  exit 1
fi

java ${jvmSettings} -jar ${TOOLFILENAME} ${bootstrapDebugString} \"-sn=${FILENAME}\" \"-ss=${SCRIPTNAME}\" \"-sv=${SCRIPTVERSION}\" ${INTERNALOCLOGINSERVER} ${INTERNALOCLOGINTOKEN} ${TOOLPROXYSETTINGS} -ibp=${DEPLOYMENTPATTERN} -c=${CONFIGNAME} -as=${AUTOMATIONSCRIPT} ${INTERNALOUTPUTPATH} ${INTERNALPDMTOC} ${INTERALPTCTOC} -isLocalMode